Package: ssmodels
Title: Sample Selection Models
Version: 2.0.2
Language: en-US
Authors@R: c(
  person( given = "Fernando", family = "de Souza Bastos", role = c( "aut", "cre" ),
          email = "fernando.bastos@ufv.br" ),
  person( given = "Wagner", family = "Barreto de Souza", role = "aut" ))
Author: Fernando de Souza Bastos [aut, cre],
  Wagner Barreto de Souza [aut]
Maintainer: Fernando de Souza Bastos <fernando.bastos@ufv.br>
Depends: R (>= 3.6.0)
Imports: MASS, sn (>= 2.1.0), miscTools (>= 0.6-26), Rdpack (>= 2.4)
Suggests: knitr (>= 1.24), testthat (>= 3.0.0), numDeriv (>=
        2016.8-1.1), maxLik (>= 1.3-6), mvtnorm (>= 1.0-11),
        sampleSelection (>= 1.2-6), kableExtra (>= 1.1.0), kfigr (>=
        1.2), ggplot2 (>= 3.2.1), gridExtra (>= 2.3)
Description: In order to facilitate the adjustment of the sample selection models
  existing in the literature, we created the 'ssmodels' package. Our package
  allows the adjustment of the classic Heckman model (Heckman (1976),
  Heckman (1979) <doi:10.2307/1912352>), and the estimation of the parameters of
  this model via the maximum likelihood method and two-step method, in addition
  to the adjustment of the Heckman-t models introduced in the literature by
  Marchenko and Genton (2012) <doi:10.1080/01621459.2012.656011> and the
  Heckman-Skew model introduced in the literature by Ogundimu and Hutton (2016)
  <doi:10.1111/sjos.12171>. We also implemented functions to adjust the
  generalized version of the Heckman model, introduced by Bastos, Barreto-Souza,
  and Genton (2021) <doi:10.5705/ss.202021.0068>, that allows the inclusion of
  covariables to the dispersion and correlation parameters, and a function to
  adjust the Heckman-BS model introduced by Bastos and Barreto-Souza (2020)
  <doi:10.1080/02664763.2020.1780570> that uses the Birnbaum-Saunders
  distribution as a joint distribution of the selection and primary regression
  variables. This package extends and complements existing R packages such as 
  'sampleSelection' (Toomet and Henningsen, 2008) and 'ssmrob' (Zhelonkin et al., 2016), providing additional robust and flexible sample selection models.
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
RdMacros: Rdpack
BugReports: https://github.com/fsbmat-ufv/ssmodels/issues
Config/testthat/edition: 3
URL: https://fsbmat-ufv.github.io/ssmodels/
NeedsCompilation: no
Config/roxygen2/version: 8.0.0
Packaged: 2026-05-30 04:06:43 UTC; Fernando
Repository: CRAN
Date/Publication: 2026-05-30 04:20:02 UTC
Built: R 4.6.0; ; 2026-05-30 05:38:02 UTC; unix
