#' Two-Step Method for Parameter Estimation of the Heckman Model
#'
#' @description
#' Estimates classical Heckman starting values using Heckman's two-step method.
#'
#' @param selection A formula for the selection equation.
#' @param outcome A formula for the outcome equation.
#' @param data A data frame containing the variables.
#'
#' @return A numeric vector containing selection coefficients, outcome coefficients,
#'   sigma and rho.
#'
#' @export
HCinitial <- function(selection, outcome, data = sys.frame(sys.parent())) {
  components <- extract_model_components(selection = selection, outcome = outcome, data = data)
  step2(components$YS, components$XS, components$YO, components$XO)
}
