% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HeckmanGe.R
\name{HeckmanGe}
\alias{HeckmanGe}
\title{Generalized Heckman Model Estimation}
\usage{
HeckmanGe(
  selection,
  outcome,
  outcomeS = 1,
  outcomeC = 1,
  data = sys.frame(sys.parent()),
  start = NULL
)
}
\arguments{
\item{selection}{Formula for the selection equation.}

\item{outcome}{Formula for the outcome equation.}

\item{outcomeS}{Covariates for the log-scale model. It may be a matrix,
vector, one-sided formula, or 1 for an intercept-only scale model.}

\item{outcomeC}{Covariates for the correlation model. It may be a matrix,
vector, one-sided formula, or 1 for an intercept-only correlation model.}

\item{data}{Data frame containing all variables.}

\item{start}{Optional starting values. If supplied on the natural classical
scale, sigma and rho are internally mapped to log(sigma) and atanh(rho).}
}
\value{
A list with the fitted model parameters and diagnostics.
}
\description{
Estimates the parameters of a generalized Heckman selection model,
allowing covariates in the scale and correlation components.
}
