% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/step2.R
\name{step2}
\alias{step2}
\title{Heckman's two-step method}
\usage{
step2(YS, XS, YO, XO)
}
\arguments{
\item{YS}{Selection vector coded as 0/1.}

\item{XS}{Selection matrix.}

\item{YO}{Outcome vector.}

\item{XO}{Covariate matrix for the outcome equation.}
}
\value{
A numeric vector with selection coefficients, outcome coefficients,
  sigma and rho.
}
\description{
Estimate classical Heckman model starting values by Heckman's two-step method.
}
