% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HCinitial.R
\name{HCinitial}
\alias{HCinitial}
\title{Two-Step Method for Parameter Estimation of the Heckman Model}
\usage{
HCinitial(selection, outcome, data = sys.frame(sys.parent()))
}
\arguments{
\item{selection}{A formula for the selection equation.}

\item{outcome}{A formula for the outcome equation.}

\item{data}{A data frame containing the variables.}
}
\value{
A numeric vector containing selection coefficients, outcome coefficients,
  sigma and rho.
}
\description{
Estimates classical Heckman starting values using Heckman's two-step method.
}
