% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.HeckmanGe.R
\name{summary.HeckmanGe}
\alias{summary.HeckmanGe}
\title{Summary of Generalized Heckman Model}
\usage{
\method{summary}{HeckmanGe}(object, ...)
}
\arguments{
\item{object}{An object of class \code{HeckmanGe}.}

\item{...}{Additional arguments (currently unused).}
}
\value{
Prints the summary output including coefficient tables and model fit statistics.
}
\description{
Print estimates of the parameters of the Generalized Heckman model using Maximum Likelihood Estimation.
}
