% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/twostep.R
\name{twostep}
\alias{twostep}
\title{Heckman's two-step method}
\usage{
twostep(selection, outcome, data = sys.frame(sys.parent()))
}
\arguments{
\item{selection}{A formula for the selection equation.}

\item{outcome}{A formula for the outcome equation.}

\item{data}{A data frame containing the variables used in the model.}
}
\value{
A numeric vector with the two-step estimates.
}
\description{
Estimate the classical Heckman model parameters by the two-step method.
}
\references{
Heckman, J. J. (1976). The common structure of statistical
models of truncation, sample selection and limited dependent variables and
a simple estimator for such models. \emph{Annals of Economic and Social
Measurement}, 5(4), 475-492.

Heckman, J. J. (1979). Sample selection bias as a specification error.
\emph{Econometrica}, 47, 153-161.
}
